@@ -26,8 +26,8 @@ enum bucket_flag {
 };
 
 enum bucket_operation_response {
-	BUCKET_EXISTS,
-	BUCKET_DOES_NOT_EXIST
+	BUCKET_EXISTS = 10,
+	BUCKET_DOES_NOT_EXIST = 11
 };
 
 // TODO: - Don't specalise size_t size_t
@@ -38,7 +38,7 @@ struct hash_bucket {
 };
 
 struct hash_table {
-	void * 	raw_data;
+	void * 					raw_data;
 	size_t 					allocated;
 	int 					_pfd;
 };
